import { 
  select, 
  csv, 
  scaleLinear, 
  max, 
  scaleBand,
  axisLeft,
  axisBottom,
  format
} from 'd3';
 
const svg = select('svg');

const width  = +svg.attr('width');
const height = +svg.attr('height');

const render = data => {
  
  const xValue = d => d.population;
  const yValue = d => d.country;
  
  const margin = {top: 40, right: 40, bottom: 40, left: 100};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, d => d.population)])
  	.range([0, innerWidth]);
  
  const yScale = scaleBand()
  	.domain(data.map(d => d.country))
  	.range([0, innerHeight])
  	.padding(0.1);
  
  console.log(yScale(data.country));
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left},${margin.top})`);
  
  const yAxis = axisLeft(yScale);
  
  
  const xAxis = axisBottom(xScale)
  	.tickFormat(number => format('.3s')(number))
  	.tickSize(-innerHeight);
  
  g.append('g').call(yAxis);
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('y', 65)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
  	.text('Population');
  
  g.selectAll('rect').data(data)
  	.enter().append('rect')
  		.attr('y', d => yScale(d.country))
  		.attr('width', d => xScale(d.population))
    	.attr('height', yScale.bandwidth());
};

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.population = d.population * 1000;
  });
	render(data);
});